<?php

namespace App\Http\Controllers;

use App\Constants\Status;
use App\Lib\CurlRequest;
use App\Models\CronJob;
use App\Models\CronJobLog;
use App\Models\Track;
use Carbon\Carbon;

class CronController extends Controller
{
    public function cron()
    {

        $general            = gs();
        $general->last_cron = now();
        $general->save();

        $crons = CronJob::with('schedule');

        if (request()->alias) {
            $crons->where('alias', request()->alias);
        } else {
            $crons->where('next_run', '<', now())->where('is_running', 1);
        }
        $crons = $crons->get();

        foreach ($crons as $cron) {

            $cronLog              = new CronJobLog();
            $cronLog->cron_job_id = $cron->id;
            $cronLog->start_at    = now();
            if ($cron->is_default) {
                $controller = new $cron->action[0];
            } else {
                try {
                    CurlRequest::curlContent($cron->url);
                } catch (\Exception $e) {
                    $cronLog->error = $e->getMessage();
                }
            }
            $cron->last_run = now();
            $cron->next_run = now()->addSeconds($cron->schedule->interval);
            $cron->save();

            $cronLog->end_at = $cron->last_run;

            $startTime         = Carbon::parse($cronLog->start_at);
            $endTime           = Carbon::parse($cronLog->end_at);
            $diffInSeconds     = $startTime->diffInSeconds($endTime);
            $cronLog->duration = $diffInSeconds;
            $cronLog->save();
        }
        if (request()->alias) {
            $notify[] = ['success', keyToTitle(request()->alias) . ' executed successfully'];
            return back()->withNotify($notify);
        }
    }

    public function upcoming_track_earning_balance()
    {
        $general = gs();

        $general->last_cron = now()->toDateTimeString();
        $general->save();

        $tracks = Track::where('status', Status::ACTIVE)->get();

        foreach ($tracks as $track) {
            $diff_in_seconds = now()->diffInSeconds($track->updated_at);
            $daily_earning   = $track->speed * $general->daily_earning;
            $per_sec_earning = $daily_earning / 86400;
            $total           = round($diff_in_seconds * $per_sec_earning, 8);
            $track->balance += $total;
            $track->save();
        }
        return 'CRON Executed.';
    }
}
