@extends($activeTemplate . 'layouts.frontend')
@section('content')
    <main>
        <img src="{{ getImage($activeTemplateTrue."images/thumbs/dotted-bg.png") }}" alt="@lang('image')" class="dotted-bg">
        <section class="dashboard pb-160">
            <div class="container">
                <div class="row gy-md-5 gy-4">
                    <div class="col-xl-12">
                        <div class="dashboard-widget text-center">
                            <div class="dashboard-widget__header">
                                <h6 class="dashboard-widget__title">{{ $account->wallet }}</h6>
                            </div>
                            <div class="dashboard-widget__body">
                                <h4 class="card__shibacoin__balance text--white deposit-address d-none py-3"></h4>
                                <img id="qrCodeImg"/>

                                <div class="d-none mb-2" id="waitingLoader">
                                    <i class="las la-spinner"></i>
                                </div>
                                <h4 class="d-none error-message text--danger mb-2"></h4>
                                <form id="depositForm">
                                    @csrf
                                    <div class="input--group">
                                        <div class="input--group__input">
                                            <div class="input-group">
                                                <input type="number" step="any" required name="amount"
                                                    class="form--control form-control" placeholder="@lang('Deposit Amount')">
                                                <span
                                                    class="input-group-text bg--base-two border--base-two text-light">{{ $general->cur_text }}</span>
                                            </div>
                                        </div>
                                        <button type="submit" class="btn btn--base">@lang('Submit')</button>
                                    </div>
                                </form>
                                <div class="dashboard-widget__content">
                                    <p class="dashboard-widget__desc">
                                        @lang('Minimum Deposit Limit'): {{ $gateway->minimum_deposit }} {{ __($general->cur_text) }}
                                        | @lang('1 DH/S') = {{ $general->dhs_price }} {{ __($general->cur_text) }}
                                        | @lang('Daily') <strong>{{ $general->daily_earning }}</strong>
                                        {{ __($general->cur_text) }} @lang('Per DH/S')
                                    </p>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-xl-12">
                        <h5 class="text-center">@lang('Your Deposit')</h5>
                        <table class="table style-two table--responsive--md">
                            <thead>
                                <tr>
                                    <th>@lang('Time')</th>
                                    <th>@lang('Wallet')</th>
                                    <th>@lang('Trx Number')</th>
                                    <th>@lang('Amount')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse ($deposits as $item)
                                    <tr>
                                        <td>
                                            <span>{{ showDateTime($item->created_at) }}</span>
                                        </td>
                                        <td>
                                            {{ $item->wallet }}
                                        </td>
                                        <td>
                                            <span>{{ $item->trx }}</span>
                                        </td>
                                        <td>
                                            <span>{{ showAmount($item->amount, 8) }} {{ __($general->cur_text) }}</span>
                                        </td>
                                    </tr>

                                @empty
                                    <tr>
                                        <td class="pill" colspan="4">@lang("DEPOSIT NOT FOUND")</td>
                                    </tr>
                                @endforelse

                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </section>
    </main>
@endsection


@push('script')
    <script>
        'use strict';
        (function($) {
            $('#depositForm').on('submit', function(e) {
                e.preventDefault();

                $('#waitingLoader').removeClass('d-none').hide().show('slow');
                $('#submitBtn').attr('disabled', 'disabled');
                $('.error-message').addClass('d-none');
                var data = $(this).serialize();

                $.ajax({
                    type: "POST",
                    url: "",
                    data: data,
                    dataType: "json",
                    success: function(data) {
                        if (data.error) {
                            $('#waitingLoader').addClass('d-none');
                            $('#submitBtn').removeAttr('disabled');
                            $('.error-message').removeClass('d-none').text(data.error);
                        } else {
                            $('#waitingLoader').addClass('d-none');
                            $('#depositForm').hide();
                            $('.deposit-address').text(data.address).removeClass('d-none');
                            let qrcode =
                                'https://chart.googleapis.com/chart?chs=300x300&cht=qr&chl=' + data
                                .address + '&choe=UTF-8';
                            $('#qrCodeImg').attr('src', qrcode);
                            $('#qrCodeImg').attr('alt',"img");
                            $('.card__shibacoin__balance').text(`Deposit Amount ${data.amount} SHIB.`)
                        }
                    }
                });
            })
        })(jQuery)
    </script>
@endpush
