@extends($activeTemplate . 'layouts.frontend')
@section('content')
    <main >
        <img src="{{ getImage($activeTemplateTrue."images/thumbs/dotted-bg.png") }}" alt="@lang('img')" class="dotted-bg">
        <section class="dashboard pb-160">
            <div class="container">
                <div class="row gy-md-5 gy-4">
                    <div class="col-xl-12">
                        <div class="dashboard-widget text-center">
                            <div class="dashboard-widget__header">
                                <h6 class="dashboard-widget__title">{{ $account->wallet }}</h6>
                            </div>
                            <div class="dashboard-widget__body">

                                <form id="withdrawForm">
                                    @csrf
                                    <div class="input--group">
                                        <div class="input--group__input">
                                            <div class="input-group">
                                                <input type="number" step="any" required name="amount" class="form--control form-control"
                                                    placeholder="@lang('Withdraw Amount')">
                                                <span
                                                    class="input-group-text bg--base-two border--base-two text-light">{{ __($general->cur_text) }}</span>
                                            </div>
                                        </div>
                                        <button type="submit" class="btn btn--base">@lang('Submit')</button>
                                    </div>
                                </form>

                                <div class="dashboard-widget__content">
                                    <p class="dashboard-widget__desc flex-between">
                                        <span class="col-lg-6">@lang('Minimum Limit'): {{ $gateway->minimum_withdraw }}
                                            {{ __($general->cur_text) }}</span>
                                        <span class="col-lg-6">@lang('Maximum Limit'): {{ $gateway->maximum_withdraw }}
                                            {{ __($general->cur_text) }}</span>
                                    </p>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-xl-12">
                        <h5 class="text-center">@lang('Your Withdrawals')</h5>
                        <table class="table style-two table--responsive--md">
                            <thead>
                                <tr>
                                    <th>@lang('Time')</th>
                                    <th>@lang('Trx Number')</th>
                                    <th>@lang('Amount')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse ($withdrawals as $item)
                                    <tr>
                                        <td>
                                            {{ showDateTime($item->created_at) }}
                                        </td>
                                        <td>
                                            <span>{{ $item->trx }}</span>
                                        </td>
                                        <td>
                                            <span>{{ showAmount($item->amount, 8) }} {{ __($general->cur_text) }}</span>
                                        </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td class="pill" colspan="4">@lang("WITHDRAW NOT FOUND")</td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </section>
    </main>
@endsection
@push('script')
    <script>
        'use strict';
        (function($) {
            $('#withdrawForm').on('submit', function(e) {
                e.preventDefault();
                let minLimit = parseFloat('{{ $gateway->minimum_withdraw }}');
                let maxLimit = parseFloat('{{ $gateway->maximum_withdraw }}');
                let inputAmount = parseFloat($(`[name="amount"]`).val());
                if (!inputAmount) {
                    notify('error', 'Withdraw amount required');
                } else if (inputAmount > maxLimit) {
                    notify('error', 'Please follow maximum withdraw limit');
                } else if (inputAmount < minLimit) {
                    notify('error', 'Please follow minimum withdraw limit');
                } else {
                    $('#submitBtn').attr('disabled', 'disabled');
                    notify("warning", 'The request is processing. Please wait for some time');
                    var data = $(this).serialize();
                    $.ajax({
                        type: "POST",
                        url: "{{ route('account.withdraw') }}",
                        data: data,
                        dataType: "json",
                        success: function(data) {
                            if (data.error) {
                                notify('error', data.error);
                                $('#submitBtn').removeAttr('disabled');
                            } else {
                                notify("success", data.success);
                            }
                        }
                    });
                }


            });
        })(jQuery)
    </script>
@endpush

